@@ -105,6 +105,18 @@ CEXPORT int indigoSetOptionXY (const char *name, int x, int y)
    INDIGO_END(-1)
 }
 
+void _indigoCheckBadValence (Molecule &mol)
+{
+   mol.restoreUnambiguousHydrogens();
+   for (int i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
+   {
+      if (mol.isPseudoAtom(i) || mol.isRSite(i))
+         continue;
+      mol.getAtomValence(i);
+      mol.getImplicitH(i);
+   }
+}
+
 CEXPORT const char * indigoCheckBadValence (int handle)
 {
    INDIGO_BEGIN
@@ -122,15 +134,7 @@ CEXPORT const char * indigoCheckBadValence (int handle)
 
          try
          {
-            int i;
-
-            for (i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
-            {
-               if (mol.isPseudoAtom(i) || mol.isRSite(i))
-                  continue;
-               mol.getAtomValence(i);
-               mol.getImplicitH(i);
-            }
+            _indigoCheckBadValence(mol);
          }
          catch (Exception &e)
          {
@@ -149,19 +153,10 @@ CEXPORT const char * indigoCheckBadValence (int handle)
 
          try
          {
-            int i, j;
-
-            for (j = rxn.begin(); j != rxn.end(); j = rxn.next(j))
+            for (int j = rxn.begin(); j != rxn.end(); j = rxn.next(j))
             {
                Molecule &mol = rxn.getMolecule(j);
-               
-               for (i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
-               {
-                  if (mol.isPseudoAtom(i) || mol.isRSite(i))
-                     continue;
-                  mol.getAtomValence(i);
-                  mol.getImplicitH(i);
-               }
+               _indigoCheckBadValence(mol);
             }
          }
          catch (Exception &e)
@@ -180,9 +175,8 @@ CEXPORT const char * indigoCheckBadValence (int handle)
 
 void _indigoCheckAmbiguousH (Molecule &mol)
 {
-   int i;
-
-   for (i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
+   mol.restoreUnambiguousHydrogens();
+   for (int i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
       if (mol.getAtomAromaticity(i) == ATOM_AROMATIC)
       {
          int atom_number = mol.getAtomNumber(i);
@@ -286,15 +280,28 @@ CEXPORT int indigoUnfoldHydrogens (int item)
 static bool _removeHydrogens (Molecule &mol)
 {
    QS_DEF(Array<int>, to_remove);
+   QS_DEF(Array<int>, sterecenters_to_validate);
    int i;
 
+   sterecenters_to_validate.clear();
    to_remove.clear();
    for (i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
       if (mol.convertableToImplicitHydrogen(i))
+      {
+         const Vertex &v = mol.getVertex(i);
+         int nei = v.neiBegin();
+         if (nei != v.neiEnd())
+         {
+            if (mol.getBondDirection(v.neiEdge(nei)))
+               sterecenters_to_validate.push(v.neiVertex(nei));
+         }
          to_remove.push(i);
+      }
 
    if (to_remove.size() > 0)
       mol.removeAtoms(to_remove);
+   for (int i = 0; i < sterecenters_to_validate.size(); i++)
+      mol.stereocenters.markBond(sterecenters_to_validate[i]);
    return to_remove.size() > 0;
 }
 
@@ -745,6 +752,13 @@ CEXPORT int indigoNormalize (int structure, const char *options)
             }
          }
       }
+
+      if (changed)
+      {
+         // Validate cs-trans because it can disappear
+         // For example: [O-]/[N+](=C\C1C=CC=CC=1)/C1C=CC=CC=1
+         mol.cis_trans.validate();
+      }
       
       return changed;
    }
