@@ -30,6 +30,7 @@ MoleculeLayoutGraph::MoleculeLayoutGraph ()
    _molecule = 0;
    _molecule_edge_mapping = 0;
    max_iterations = 0;
+   cancellation = 0;
    _flipped = false;
 }
 
@@ -415,6 +416,8 @@ void MoleculeLayoutGraph::_layoutMultipleComponents (BaseMolecule & molecule, bo
    {
       Filter comp_filter(decomposition.ptr(), Filter::EQ, i);
       MoleculeLayoutGraph &component = components.push();
+      
+      component.cancellation = cancellation;
 
       component.makeLayoutSubgraph(*this, comp_filter);
       component.max_iterations = max_iterations;
