@@ -1390,6 +1390,9 @@ void Molecule::invalidateHCounters ()
 
 void Molecule::checkForConsistency (Molecule &mol)
 {
+   // Try to restore hydrogens in aromatic cycles first
+   mol.restoreUnambiguousHydrogens();
+
    int i;
    for (i = mol.vertexBegin(); i < mol.vertexEnd(); i = mol.vertexNext(i))
    {
@@ -1398,14 +1401,12 @@ void Molecule::checkForConsistency (Molecule &mol)
       if (mol.isPseudoAtom(i) || mol.isRSite(i))
          continue;
 
-      // check that all explicit hydrogens are lone or 1-connected
-      if (mol.getAtomNumber(i) == ELEM_H && vertex.degree() > 1)
-         throw Element::Error("%d-connected hydrogen atom", vertex.degree());
+      // check that we are sure about valence
+      // (if the radical is not set, it is calculated from the valence anyway)
+      int val = mol.getAtomValence(i);
 
       // check that we are sure about implicit H counter and valence
       mol.getImplicitH(i);
-      mol.getAtomValence(i);
-      // (if the radical is not set, it is calculated from the valence anyway)
    }
 }
 
@@ -1485,3 +1486,8 @@ void Molecule::invalidateAtom (int index, int mask)
 {
    BaseMolecule::invalidateAtom(index, mask);
 }
+
+bool Molecule::restoreUnambiguousHydrogens ()
+{
+   return MoleculeDearomatizer::restoreUnambiguousHydrogens(*this);
+}
