@@ -1536,3 +1536,24 @@ bool MoleculeDearomatizer::restoreHydrogens (Molecule &mol, const AromaticityOpt
    }
    return all_dearomatzied;
 }
+
+bool MoleculeDearomatizer::restoreUnambiguousHydrogens (Molecule &mol)
+{
+   bool found_invalid_h = false;
+   for (int i = mol.vertexBegin(); i != mol.vertexEnd(); i = mol.vertexNext(i))
+   {
+      if (mol.isRSite(i) || mol.isPseudoAtom(i))
+         continue;
+
+      if (mol.getImplicitH_NoThrow(i, -1) == -1)
+         found_invalid_h = true;
+   }
+   if (found_invalid_h)
+   {
+      AromaticityOptions options;
+      options.method = AromaticityOptions::GENERIC;
+      options.unique_dearomatization = true;
+      return MoleculeDearomatizer::restoreHydrogens(mol, options);
+   }
+   return true;
+}
